from django.db import models

from portailuser.fields import PortailUserDbPhoneField

from gestion.inscriptions.models import GENRES, Inscription


class InscriptionLimitee(models.Model):
    """
    InscriptionLimitee est une variante de gestion.inscriptions.Inscription vouée à être remplie par les utilisateurs eux-mêmes.
    C'est pourquoi certains champs de Inscription ne sont pas accessibles, car un utilisateur ne doit pas pouvoir s'autoinscrire
    à l'AE ou à la frappe.
    """

    attributes = [
        "nom",
        "prenom",
        "date_naissance",
        "genre",
        "promo",
        "filiere",
        "email",
        "adresse",
        "tel_mobile",
        "date_ajout",
        # les 4 dernières entrées sont bien copiées depuis l'object courant vers l'inscription cible, mais ils sont créés dns views.nouvelle au lieu d'être définis ici
        "etat",
        "ecole",
        "login",
        "mdp",
    ]

    # Informations obligatoires
    nom = models.CharField(max_length=64, verbose_name="Nom")
    prenom = models.CharField(max_length=64, verbose_name="Prénom")
    email = models.EmailField(verbose_name="Email personnel")
    date_naissance = models.DateField(verbose_name="Date de naissance")
    genre = models.SmallIntegerField(choices=GENRES, verbose_name="Genre")

    # Informations école/AE/INP-net
    promo = models.IntegerField(verbose_name="Promo")
    filiere = models.CharField(max_length=64, verbose_name="Filière")

    # Informations facultatives
    adresse = models.TextField(blank=True, verbose_name="Adresse personnelle (optionnel)")

    tel_mobile = PortailUserDbPhoneField(max_length=32, blank=True, verbose_name="Téléphone mobile (optionnel)")

    photo = models.ImageField(blank=True, verbose_name="Photo pour apparaître sur l'annuaire (optionnel)")

    date_ajout = models.DateTimeField(auto_now_add=True, editable=False)

    # Les objets InscriptionLimitee sont convertis en gestion.inscriptions.Inscription à la volée
    def save(self):
        args = {}

        for field_name in self.attributes:
            args[field_name] = getattr(self, field_name)

        inscr = Inscription(**args)

        inscr.save()

        return inscr
